@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -23,11 +23,11 @@
 
 #include <named/types.h>
 
-#define NS_STATSCHANNEL_HTTPPORT		80
+#define NAMED_STATSCHANNEL_HTTPPORT		80
 
 isc_result_t
-ns_statschannels_configure(ns_server_t *server, const cfg_obj_t *config,
-			   cfg_aclconfctx_t *aclconfctx);
+named_statschannels_configure(named_server_t *server, const cfg_obj_t *config,
+			      cfg_aclconfctx_t *aclconfctx);
 /*%<
  * [Re]configure the statistics channels.
  *
@@ -40,13 +40,13 @@ ns_statschannels_configure(ns_server_t *server, const cfg_obj_t *config,
 
 
 void
-ns_statschannels_shutdown(ns_server_t *server);
+named_statschannels_shutdown(named_server_t *server);
 /*%<
  * Initiate shutdown of all the statistics channel listeners.
  */
 
 isc_result_t
-ns_stats_dump(ns_server_t *server, FILE *fp);
+named_stats_dump(named_server_t *server, FILE *fp);
 /*%<
  * Dump statistics counters managed by the server to the file fp.
  */
