@@ -59,54 +59,6 @@ static int singletonfd = -1;
 #define ISC_FACILITY LOG_DAEMON
 #endif
 
-/*
- * If there's no <sys/capability.h>, we don't care about <sys/prctl.h>
- */
-#ifndef HAVE_SYS_CAPABILITY_H
-#undef HAVE_SYS_PRCTL_H
-#endif
-
-/*
- * Linux defines:
- *	(T) HAVE_LINUXTHREADS
- *	(C) HAVE_SYS_CAPABILITY_H
- *	(P) HAVE_SYS_PRCTL_H
- * The possible cases are:
- *	none:	setuid() normally
- *	T:	no setuid()
- *	C:	setuid() normally, drop caps (keep CAP_SETUID)
- *	T+C:	no setuid(), drop caps (don't keep CAP_SETUID)
- *	T+C+P:	setuid() early, drop caps (keep CAP_SETUID)
- *	C+P:	setuid() normally, drop caps (keep CAP_SETUID)
- *	P:	not possible
- *	T+P:	not possible
- *
- * if (C)
- *	caps = BIND_SERVICE + CHROOT + SETGID
- *	if ((T && C && P) || !T)
- *		caps += SETUID
- *	endif
- *	capset(caps)
- * endif
- * if (T && C && P && -u)
- *	setuid()
- * else if (T && -u)
- *	fail
- * --> start threads
- * if (!T && -u)
- *	setuid()
- * if (C && (P || !-u))
- *	caps = BIND_SERVICE
- *	capset(caps)
- * endif
- *
- * It will be nice when Linux threads work properly with setuid().
- */
-
-#ifdef HAVE_LINUXTHREADS
-static pid_t mainpid = 0;
-#endif
-
 static struct passwd *runas_pw = NULL;
 static bool done_setuid = false;
 static int dfd[2] = { -1, -1 };
@@ -117,10 +69,7 @@ static bool non_root = false;
 static bool non_root_caps = false;
 
 #include <sys/capability.h>
-
-#ifdef HAVE_SYS_PRCTL_H
-#include <sys/prctl.h>		/* Required for prctl(). */
-#endif /* HAVE_SYS_PRCTL_H */
+#include <sys/prctl.h>
 
 static void
 linux_setcaps(cap_t caps) {
@@ -201,15 +150,11 @@ linux_initialprivs(void) {
 	 */
 	SET_CAP(CAP_SYS_CHROOT);
 
-#if defined(HAVE_SYS_PRCTL_H) || !defined(HAVE_LINUXTHREADS)
 	/*
-	 * We can setuid() only if either the kernel supports keeping
-	 * capabilities after setuid() (which we don't know until we've
-	 * tried) or we're not using threads.  If either of these is
-	 * true, we want the setuid capability.
+	 * We need setuid() as the kernel supports keeping capabilities after
+	 * setuid().
 	 */
 	SET_CAP(CAP_SETUID);
-#endif
 
 	/*
 	 * Since we call initgroups, we need this.
@@ -275,7 +220,6 @@ linux_minprivs(void) {
 	FREE_CAP;
 }
 
-#ifdef HAVE_SYS_PRCTL_H
 static void
 linux_keepcaps(void) {
 	char strbuf[ISC_STRERRORSIZE];
@@ -295,11 +239,9 @@ linux_keepcaps(void) {
 			non_root = true;
 	}
 }
-#endif
 
 #endif	/* HAVE_SYS_CAPABILITY_H */
 
-
 static void
 setup_syslog(const char *progname) {
 	int options;
@@ -317,9 +259,6 @@ named_os_init(const char *progname) {
 #ifdef HAVE_SYS_CAPABILITY_H
 	linux_initialprivs();
 #endif
-#ifdef HAVE_LINUXTHREADS
-	mainpid = getpid();
-#endif
 #ifdef SIGXFSZ
 	signal(SIGXFSZ, SIG_IGN);
 #endif
@@ -362,10 +301,6 @@ named_os_daemonize(void) {
 	 * We're the child.
 	 */
 
-#ifdef HAVE_LINUXTHREADS
-	mainpid = getpid();
-#endif
-
 	if (setsid() == -1) {
 		strerror_r(errno, strbuf, sizeof(strbuf));
 		named_main_earlyfatal("setsid(): %s", strbuf);
@@ -499,20 +434,6 @@ named_os_changeuser(void) {
 
 	done_setuid = true;
 
-#ifdef HAVE_LINUXTHREADS
-#ifdef HAVE_SYS_CAPABILITY_H
-	if (!non_root_caps) {
-		named_main_earlyfatal("-u with Linux threads not supported: "
-				      "requires kernel support for "
-				      "prctl(PR_SET_KEEPCAPS)");
-	}
-#else
-	named_main_earlyfatal("-u with Linux threads not supported: "
-			      "no capabilities support or capabilities "
-			      "disabled at build time");
-#endif
-#endif
-
 	if (setgid(runas_pw->pw_gid) < 0) {
 		strerror_r(errno, strbuf, sizeof(strbuf));
 		named_main_earlyfatal("setgid(): %s", strbuf);
@@ -523,7 +444,7 @@ named_os_changeuser(void) {
 		named_main_earlyfatal("setuid(): %s", strbuf);
 	}
 
-#if defined(HAVE_SYS_PRCTL_H) && defined(PR_SET_DUMPABLE)
+#if defined(HAVE_SYS_CAPABILITY_H)
 	/*
 	 * Restore the ability of named to drop core after the setuid()
 	 * call has disabled it.
@@ -533,8 +454,7 @@ named_os_changeuser(void) {
 		named_main_earlywarning("prctl(PR_SET_DUMPABLE) failed: %s",
 					strbuf);
 	}
-#endif
-#if defined(HAVE_SYS_CAPABILITY_H) && !defined(HAVE_LINUXTHREADS)
+
 	linux_minprivs();
 #endif
 }
@@ -548,7 +468,7 @@ ns_os_uid(void) {
 
 void
 named_os_adjustnofile(void) {
-#ifdef HAVE_LINUXTHREADS
+#if defined(__linux__)
 	isc_result_t result;
 	isc_resourcevalue_t newvalue;
 
@@ -566,15 +486,9 @@ named_os_adjustnofile(void) {
 
 void
 named_os_minprivs(void) {
-#ifdef HAVE_SYS_PRCTL_H
+#if defined(HAVE_SYS_CAPABILITY_H)
 	linux_keepcaps();
-#endif
-
-#ifdef HAVE_LINUXTHREADS
-	named_os_changeuser(); /* Call setuid() before threads are started */
-#endif
-
-#if defined(HAVE_SYS_CAPABILITY_H) && defined(HAVE_LINUXTHREADS)
+	named_os_changeuser();
 	linux_minprivs();
 #endif
 }
@@ -759,21 +673,16 @@ named_os_openfile(const char *filename, mode_t mode, bool switch_user) {
 	free(f);
 
 	if (switch_user && runas_pw != NULL) {
-#ifndef HAVE_LINUXTHREADS
 		gid_t oldgid = getgid();
-#endif
 		/* Set UID/GID to the one we'll be running with eventually */
 		setperms(runas_pw->pw_uid, runas_pw->pw_gid);
 
 		fd = safe_open(filename, mode, false);
 
-#ifndef HAVE_LINUXTHREADS
 		/* Restore UID/GID to root */
 		setperms(0, oldgid);
-#endif /* HAVE_LINUXTHREADS */
 
 		if (fd == -1) {
-#ifndef HAVE_LINUXTHREADS
 			fd = safe_open(filename, mode, false);
 			if (fd != -1) {
 				named_main_earlywarning("Required root "
@@ -786,13 +695,6 @@ named_os_openfile(const char *filename, mode_t mode, bool switch_user) {
 			named_main_earlywarning("Please check file and "
 						"directory permissions "
 						"or reconfigure the filename.");
-#else /* HAVE_LINUXTHREADS */
-			named_main_earlywarning("Could not open "
-						"'%s'.", filename);
-			named_main_earlywarning("Please check file and "
-						"directory permissions "
-						"or reconfigure the filename.");
-#endif /* HAVE_LINUXTHREADS */
 		}
 	} else {
 		fd = safe_open(filename, mode, false);
@@ -846,11 +748,7 @@ named_os_writepidfile(const char *filename, bool first_time) {
 		cleanup_pidfile();
 		return;
 	}
-#ifdef HAVE_LINUXTHREADS
-	pid = mainpid;
-#else
 	pid = getpid();
-#endif
 	if (fprintf(fh, "%ld\n", (long)pid) < 0) {
 		(*report)("fprintf() to pid file '%s' failed", filename);
 		(void)fclose(fh);
@@ -956,11 +854,7 @@ named_os_shutdownmsg(char *command, isc_buffer_t *text) {
 		return;
 	}
 
-#ifdef HAVE_LINUXTHREADS
-	pid = mainpid;
-#else
 	pid = getpid();
-#endif
 
 	(void)isc_buffer_printf(text, "pid: %ld", (long)pid);
 }
