@@ -27,6 +27,13 @@ do
 	sleep 1
 done
 
+n=`expr $n + 1`
+echo_i "checking that an unsupported algorithm is not used for signing ($n)"
+ret=0
+grep -q "algorithm is unsupported" ns3/named.run || ret=1
+if [ $ret != 0 ]; then echo_i "failed"; fi
+status=`expr $status + $ret`
+
 n=`expr $n + 1`
 echo_i "checking that rrsigs are replaced with ksk only ($n)"
 ret=0
@@ -332,7 +339,7 @@ n=`expr $n + 1`
 echo_i "check adding of record to unsigned master ($n)"
 ret=0
 cp ns3/master2.db.in ns3/master.db
-$RNDCCMD 10.53.0.3 reload master 2>&1 | sed 's/^/ns3 /' | cat_i
+rndc_reload ns3 10.53.0.3 master
 for i in 1 2 3 4 5 6 7 8 9
 do
 	ans=0
@@ -350,7 +357,7 @@ n=`expr $n + 1`
 echo_i "check adding record fails when SOA serial not changed ($n)"
 ret=0
 echo "c A 10.0.0.3" >> ns3/master.db
-$RNDCCMD 10.53.0.3 reload 2>&1 | sed 's/^/ns3 /' | cat_i
+rndc_reload ns3 10.53.0.3
 sleep 1
 $DIG $DIGOPTS @10.53.0.3 c.master A > dig.out.ns3.test$n
 grep "NXDOMAIN" dig.out.ns3.test$n > /dev/null || ret=1
@@ -438,7 +445,7 @@ EOF
 [ -f ns3/dynamic.db.jnl ] || { ret=1 ; echo_i "journal does not exist (posttest)" ; }
 
 for i in 1 2 3 4 5 6 7 8 9 10
-do 
+do
 	ans=0
 	$DIG $DIGOPTS @10.53.0.3 e.dynamic > dig.out.ns3.test$n
 	grep "status: NOERROR" dig.out.ns3.test$n > /dev/null || ans=1
@@ -455,14 +462,14 @@ status=`expr $status + $ret`
 n=`expr $n + 1`
 echo_i "stop bump in the wire signer server ($n)"
 ret=0
-$PERL ../stop.pl . ns3 || ret=1
+$PERL ../stop.pl inline ns3 || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
 status=`expr $status + $ret`
 
 n=`expr $n + 1`
 echo_i "restart bump in the wire signer server ($n)"
 ret=0
-$PERL ../start.pl --noclean --restart --port ${PORT} . ns3 || ret=1
+$PERL ../start.pl --noclean --restart --port ${PORT} inline ns3 || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
 status=`expr $status + $ret`
 
@@ -605,7 +612,7 @@ status=`expr $status + $ret`
 copy_setports ns5/named.conf.post ns5/named.conf
 (cd ns5; $KEYGEN -q -a rsasha256 bits) > /dev/null 2>&1
 (cd ns5; $KEYGEN -q -a rsasha256 -f KSK bits) > /dev/null 2>&1
-$RNDCCMD 10.53.0.5 reload 2>&1 | sed 's/^/ns5 /' | cat_i
+rndc_reload ns5 10.53.0.5
 for i in 1 2 3 4 5 6 7 8 9 10
 do
 	ret=0
@@ -635,7 +642,7 @@ echo_i "checking rndc freeze/thaw of dynamic inline zone ($n)"
 ret=0
 $RNDCCMD 10.53.0.3 freeze dynamic > freeze.test$n 2>&1 || ret=1
 sleep 1
-awk '$2 == ";" && $3 == "serial" { printf("%d %s %s\n", $1 + 1, $2, $3); next; }
+awk '$2 == ";" && $3 ~ /serial/ { printf("%d %s %s\n", $1 + 1, $2, $3); next; }
      { print; }
      END { print "freeze1.dynamic. 0 TXT freeze1"; } ' ns3/dynamic.db > ns3/dynamic.db.new
 mv ns3/dynamic.db.new ns3/dynamic.db
@@ -665,7 +672,7 @@ echo_i "checking rndc freeze/thaw of server ($n)"
 ret=0
 $RNDCCMD 10.53.0.3 freeze > freeze.test$n 2>&1 || ret=1
 sleep 1
-awk '$2 == ";" && $3 == "serial" { printf("%d %s %s\n", $1 + 1, $2, $3); next; }
+awk '$2 == ";" && $3 ~ /serial/ { printf("%d %s %s\n", $1 + 1, $2, $3); next; }
      { print; }
      END { print "freeze2.dynamic. 0 TXT freeze2"; } ' ns3/dynamic.db > ns3/dynamic.db.new
 mv ns3/dynamic.db.new ns3/dynamic.db
@@ -869,7 +876,7 @@ status=`expr $status + $ret`
 n=`expr $n + 1`
 echo_i "stop bump in the wire signer server ($n)"
 ret=0
-$PERL ../stop.pl . ns3 || ret=1
+$PERL ../stop.pl inline ns3 || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
 status=`expr $status + $ret`
 
@@ -880,7 +887,7 @@ rm ns3/master.db.jnl
 n=`expr $n + 1`
 echo_i "restart bump in the wire signer server ($n)"
 ret=0
-$PERL ../start.pl --noclean --restart --port ${PORT} . ns3 || ret=1
+$PERL ../start.pl --noclean --restart --port ${PORT} inline ns3 || ret=1
 if [ $ret != 0 ]; then echo_i "failed"; fi
 status=`expr $status + $ret`
 
@@ -909,7 +916,7 @@ ret=1
 sleep 1
 nextpart ns3/named.run > /dev/null
 cp ns3/master5.db.in ns3/master.db
-$RNDCCMD 10.53.0.3 reload 2>&1 | sed 's/^/ns3 /' | cat_i
+rndc_reload ns3 10.53.0.3
 for i in 1 2 3 4 5 6 7 8 9 10
 do
 	if nextpart ns3/named.run | grep "zone master.*sending notifies" > /dev/null; then
@@ -1323,18 +1330,18 @@ done
 if [ $ans != 0 ]; then ret=1; fi
 # Halt rather than stopping the server to prevent the master file from being
 # flushed upon shutdown since we specifically want to avoid it.
-$PERL $SYSTEMTESTTOP/stop.pl --use-rndc --halt --port ${CONTROLPORT} . ns3
+$PERL $SYSTEMTESTTOP/stop.pl --use-rndc --halt --port ${CONTROLPORT} inline ns3
 ensure_sigs_only_in_journal delayedkeys ns3/delayedkeys.db.signed
-$PERL $SYSTEMTESTTOP/start.pl --noclean --restart --port ${PORT} . ns3
+$PERL $SYSTEMTESTTOP/start.pl --noclean --restart --port ${PORT} inline ns3
 # At this point, the raw zone journal will not have a source serial set.  Upon
 # server startup, receive_secure_serial() will rectify that, update SOA, resign
 # it, and schedule its future resign.  This will cause "rndc zonestatus" to
 # return delayedkeys/SOA as the next node to resign, so we restart the server
 # once again; with the raw zone journal now having a source serial set,
 # receive_secure_serial() should refrain from introducing any zone changes.
-$PERL $SYSTEMTESTTOP/stop.pl --use-rndc --halt --port ${CONTROLPORT} . ns3
+$PERL $SYSTEMTESTTOP/stop.pl --use-rndc --halt --port ${CONTROLPORT} inline ns3
 ensure_sigs_only_in_journal delayedkeys ns3/delayedkeys.db.signed
-$PERL $SYSTEMTESTTOP/start.pl --noclean --restart --port ${PORT} . ns3
+$PERL $SYSTEMTESTTOP/start.pl --noclean --restart --port ${PORT} inline ns3
 # We can now test whether the secure zone journal was correctly processed:
 # unless the records contained in it were scheduled for resigning, no resigning
 # event will be scheduled at all since the secure zone master file contains no
