@@ -526,7 +526,7 @@ destroy_disp(isc_task_t *task, isc_event_t *event) {
 
 	if (disp->sepool != NULL) {
 		isc_mempool_destroy(&disp->sepool);
-		(void)isc_mutex_destroy(&disp->sepool_lock);
+		isc_mutex_destroy(&disp->sepool_lock);
 	}
 
 	if (disp->socket != NULL)
@@ -1625,7 +1625,7 @@ destroy_mgr(dns_dispatchmgr_t **mgrp) {
 
 	mgr->magic = 0;
 	mgr->mctx = NULL;
-	DESTROYLOCK(&mgr->lock);
+	isc_mutex_destroy(&mgr->lock);
 	mgr->state = 0;
 
 	isc_mempool_destroy(&mgr->depool);
@@ -1636,16 +1636,16 @@ destroy_mgr(dns_dispatchmgr_t **mgrp) {
 	if (mgr->spool != NULL)
 		isc_mempool_destroy(&mgr->spool);
 
-	DESTROYLOCK(&mgr->spool_lock);
-	DESTROYLOCK(&mgr->bpool_lock);
-	DESTROYLOCK(&mgr->dpool_lock);
-	DESTROYLOCK(&mgr->rpool_lock);
-	DESTROYLOCK(&mgr->depool_lock);
+	isc_mutex_destroy(&mgr->spool_lock);
+	isc_mutex_destroy(&mgr->bpool_lock);
+	isc_mutex_destroy(&mgr->dpool_lock);
+	isc_mutex_destroy(&mgr->rpool_lock);
+	isc_mutex_destroy(&mgr->depool_lock);
 
 	if (mgr->qid != NULL)
 		qid_destroy(mctx, &mgr->qid);
 
-	DESTROYLOCK(&mgr->buffer_lock);
+	isc_mutex_destroy(&mgr->buffer_lock);
 
 	if (mgr->blackhole != NULL)
 		dns_acl_detach(&mgr->blackhole);
@@ -1760,39 +1760,19 @@ dns_dispatchmgr_create(isc_mem_t *mctx, dns_dispatchmgr_t **mgrp)
 	mgr->blackhole = NULL;
 	mgr->stats = NULL;
 
-	result = isc_mutex_init(&mgr->lock);
-	if (result != ISC_R_SUCCESS)
-		goto deallocate;
-
-	result = isc_mutex_init(&mgr->buffer_lock);
-	if (result != ISC_R_SUCCESS)
-		goto kill_lock;
-
-	result = isc_mutex_init(&mgr->depool_lock);
-	if (result != ISC_R_SUCCESS)
-		goto kill_buffer_lock;
-
-	result = isc_mutex_init(&mgr->rpool_lock);
-	if (result != ISC_R_SUCCESS)
-		goto kill_depool_lock;
-
-	result = isc_mutex_init(&mgr->dpool_lock);
-	if (result != ISC_R_SUCCESS)
-		goto kill_rpool_lock;
-
-	result = isc_mutex_init(&mgr->bpool_lock);
-	if (result != ISC_R_SUCCESS)
-		goto kill_dpool_lock;
-
-	result = isc_mutex_init(&mgr->spool_lock);
-	if (result != ISC_R_SUCCESS)
-		goto kill_bpool_lock;
+	isc_mutex_init(&mgr->lock);
+	isc_mutex_init(&mgr->buffer_lock);
+	isc_mutex_init(&mgr->depool_lock);
+	isc_mutex_init(&mgr->rpool_lock);
+	isc_mutex_init(&mgr->dpool_lock);
+	isc_mutex_init(&mgr->bpool_lock);
+	isc_mutex_init(&mgr->spool_lock);
 
 	mgr->depool = NULL;
 	if (isc_mempool_create(mgr->mctx, sizeof(dns_dispatchevent_t),
 			       &mgr->depool) != ISC_R_SUCCESS) {
 		result = ISC_R_NOMEMORY;
-		goto kill_spool_lock;
+		goto kill_locks;
 	}
 
 	mgr->rpool = NULL;
@@ -1866,21 +1846,14 @@ dns_dispatchmgr_create(isc_mem_t *mctx, dns_dispatchmgr_t **mgrp)
 	isc_mempool_destroy(&mgr->rpool);
  kill_depool:
 	isc_mempool_destroy(&mgr->depool);
- kill_spool_lock:
-	DESTROYLOCK(&mgr->spool_lock);
- kill_bpool_lock:
-	DESTROYLOCK(&mgr->bpool_lock);
- kill_dpool_lock:
-	DESTROYLOCK(&mgr->dpool_lock);
- kill_rpool_lock:
-	DESTROYLOCK(&mgr->rpool_lock);
- kill_depool_lock:
-	DESTROYLOCK(&mgr->depool_lock);
- kill_buffer_lock:
-	DESTROYLOCK(&mgr->buffer_lock);
- kill_lock:
-	DESTROYLOCK(&mgr->lock);
- deallocate:
+ kill_locks:
+	isc_mutex_destroy(&mgr->spool_lock);
+	isc_mutex_destroy(&mgr->bpool_lock);
+	isc_mutex_destroy(&mgr->dpool_lock);
+	isc_mutex_destroy(&mgr->rpool_lock);
+	isc_mutex_destroy(&mgr->depool_lock);
+	isc_mutex_destroy(&mgr->buffer_lock);
+	isc_mutex_destroy(&mgr->lock);
 	isc_mem_put(mctx, mgr, sizeof(dns_dispatchmgr_t));
 	isc_mem_detach(&mctx);
 
@@ -2262,7 +2235,6 @@ qid_allocate(dns_dispatchmgr_t *mgr, unsigned int buckets,
 {
 	dns_qid_t *qid;
 	unsigned int i;
-	isc_result_t result;
 
 	REQUIRE(VALID_DISPATCHMGR(mgr));
 	REQUIRE(buckets < 2097169);  /* next prime > 65536 * 32 */
@@ -2292,17 +2264,7 @@ qid_allocate(dns_dispatchmgr_t *mgr, unsigned int buckets,
 		}
 	}
 
-	result = isc_mutex_init(&qid->lock);
-	if (result != ISC_R_SUCCESS) {
-		if (qid->sock_table != NULL) {
-			isc_mem_put(mgr->mctx, qid->sock_table,
-				    buckets * sizeof(dispsocketlist_t));
-		}
-		isc_mem_put(mgr->mctx, qid->qid_table,
-			    buckets * sizeof(dns_displist_t));
-		isc_mem_put(mgr->mctx, qid, sizeof(*qid));
-		return (result);
-	}
+	isc_mutex_init(&qid->lock);
 
 	for (i = 0; i < buckets; i++) {
 		ISC_LIST_INIT(qid->qid_table[i]);
@@ -2334,7 +2296,7 @@ qid_destroy(isc_mem_t *mctx, dns_qid_t **qidp) {
 		isc_mem_put(mctx, qid->sock_table,
 			    qid->qid_nbuckets * sizeof(dispsocketlist_t));
 	}
-	DESTROYLOCK(&qid->lock);
+	isc_mutex_destroy(&qid->lock);
 	isc_mem_put(mctx, qid, sizeof(*qid));
 }
 
@@ -2385,9 +2347,7 @@ dispatch_allocate(dns_dispatchmgr_t *mgr, unsigned int maxrequests,
 	disp->portpool = NULL;
 	disp->dscp = -1;
 
-	result = isc_mutex_init(&disp->lock);
-	if (result != ISC_R_SUCCESS)
-		goto deallocate;
+	isc_mutex_init(&disp->lock);
 
 	disp->failsafe_ev = allocate_devent(disp);
 	if (disp->failsafe_ev == NULL) {
@@ -2404,8 +2364,7 @@ dispatch_allocate(dns_dispatchmgr_t *mgr, unsigned int maxrequests,
 	 * error returns
 	 */
  kill_lock:
-	DESTROYLOCK(&disp->lock);
- deallocate:
+	isc_mutex_destroy(&disp->lock);
 	isc_mempool_put(mgr->dpool, disp);
 
 	return (result);
@@ -2457,7 +2416,7 @@ dispatch_free(dns_dispatch_t **dispp) {
 		isc_mempool_destroy(&disp->portpool);
 
 	disp->mgr = NULL;
-	DESTROYLOCK(&disp->lock);
+	isc_mutex_destroy(&disp->lock);
 	disp->magic = 0;
 	isc_mempool_put(mgr->dpool, disp);
 }
@@ -2959,7 +2918,7 @@ dispatch_createudp(dns_dispatchmgr_t *mgr, isc_socketmgr_t *sockmgr,
 	}
 	for (i = 0; i < disp->ntasks; i++) {
 		disp->task[i] = NULL;
-		result = isc_task_create(taskmgr, 50, &disp->task[i]);
+		result = isc_task_create(taskmgr, 0, &disp->task[i]);
 		if (result != ISC_R_SUCCESS) {
 			while (--i >= 0) {
 				isc_task_shutdown(disp->task[i]);
@@ -2987,10 +2946,7 @@ dispatch_createudp(dns_dispatchmgr_t *mgr, isc_socketmgr_t *sockmgr,
 		goto kill_ctlevent;
 	}
 
-	result = isc_mutex_init(&disp->sepool_lock);
-	if (result != ISC_R_SUCCESS) {
-		goto kill_sepool;
-	}
+	isc_mutex_init(&disp->sepool_lock);
 
 	isc_mempool_setname(disp->sepool, "disp_sepool");
 	isc_mempool_setmaxalloc(disp->sepool, 32768);
@@ -3020,8 +2976,6 @@ dispatch_createudp(dns_dispatchmgr_t *mgr, isc_socketmgr_t *sockmgr,
 	/*
 	 * Error returns.
 	 */
- kill_sepool:
-	isc_mempool_destroy(&disp->sepool);
  kill_ctlevent:
 	isc_event_free(&disp->ctlevent);
  kill_task:
@@ -3692,9 +3646,7 @@ dns_dispatchset_create(isc_mem_t *mctx, isc_socketmgr_t *sockmgr,
 		return (ISC_R_NOMEMORY);
 	memset(dset, 0, sizeof(*dset));
 
-	result = isc_mutex_init(&dset->lock);
-	if (result != ISC_R_SUCCESS)
-		goto fail_alloc;
+	isc_mutex_init(&dset->lock);
 
 	dset->dispatches = isc_mem_get(mctx, sizeof(dns_dispatch_t *) * n);
 	if (dset->dispatches == NULL) {
@@ -3737,9 +3689,7 @@ dns_dispatchset_create(isc_mem_t *mctx, isc_socketmgr_t *sockmgr,
 		isc_mem_detach(&dset->mctx);
 
  fail_lock:
-	DESTROYLOCK(&dset->lock);
-
- fail_alloc:
+	isc_mutex_destroy(&dset->lock);
 	isc_mem_put(mctx, dset, sizeof(dns_dispatchset_t));
 	return (result);
 }
@@ -3769,7 +3719,7 @@ dns_dispatchset_destroy(dns_dispatchset_t **dsetp) {
 		dns_dispatch_detach(&(dset->dispatches[i]));
 	isc_mem_put(dset->mctx, dset->dispatches,
 		    sizeof(dns_dispatch_t *) * dset->ndisp);
-	DESTROYLOCK(&dset->lock);
+	isc_mutex_destroy(&dset->lock);
 	isc_mem_putanddetach(&dset->mctx, dset, sizeof(dns_dispatchset_t));
 
 	*dsetp = NULL;
