@@ -19,7 +19,6 @@
 
 #include <isc/mem.h>
 #include <isc/safe.h>
-#include <isc/sha2.h>
 #include <isc/result.h>
 #include <isc/string.h>
 #include <isc/util.h>
@@ -355,16 +354,13 @@ openssleddsa_sign(dst_context_t *dctx, isc_buffer_t *sig) {
 
 	isc_buffer_usedregion(buf, &tbsreg);
 
-	if (EVP_DigestSignInit(ctx, NULL, NULL, NULL, pkey))
+	if (EVP_DigestSignInit(ctx, NULL, NULL, NULL, pkey) != 1) {
 		DST_RET(dst__openssl_toresult3(dctx->category,
 					       "EVP_DigestSignInit",
 					       ISC_R_FAILURE));
-	if (EVP_DigestSignUpdate(ctx, tbsreg.base, tbsreg.length) != 1) {
-		DST_RET(dst__openssl_toresult3(dctx->category,
-					       "EVP_DigestSignUpdate",
-					       DST_R_SIGNFAILURE));
 	}
-	if (EVP_DigestSignFinal(ctx, sigreg.base, &siglen) != 1) {
+	if (EVP_DigestSign(ctx, sigreg.base, &siglen,
+			   tbsreg.base, tbsreg.length) != 1) {
 		DST_RET(dst__openssl_toresult3(dctx->category,
 					       "EVP_DigestSign",
 					       DST_R_SIGNFAILURE));
@@ -423,13 +419,8 @@ openssleddsa_verify(dst_context_t *dctx, const isc_region_t *sig) {
 					       ISC_R_FAILURE));
 	}
 
-	if (EVP_DigestVerifyUpdate(ctx, tbsreg.base, tbsreg.length) != 1) {
-		DST_RET(dst__openssl_toresult3(dctx->category,
-					       "EVP_DigestVerifyUpdate",
-					       ISC_R_FAILURE));
-	}
-
-	status = EVP_DigestVerifyFinal(ctx, sig->base, siglen);
+	status = EVP_DigestVerify(ctx, sig->base, siglen,
+				  tbsreg.base, tbsreg.length);
 
 	switch (status) {
 	case 1:
@@ -578,6 +569,7 @@ openssleddsa_todns(const dst_key_t *key, isc_buffer_t *data) {
 		return (result);
 	default:
 		INSIST(0);
+		ISC_UNREACHABLE();
 	}
 }
 
