@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -14,7 +14,7 @@
 #include <isc/meminfo.h>
 #include <inttypes.h>
 #include <unistd.h>
-#if defined(HAVE_SYS_SYSCTL_H) && !defined(__linux__)
+#ifdef HAVE_SYS_SYSCTL_H
 #include <sys/sysctl.h>
 #endif
 
@@ -34,14 +34,7 @@ isc_meminfo_totalphys(void) {
 		return (size);
 #endif
 #if defined(_SC_PHYS_PAGES) && defined(_SC_PAGESIZE)
-	long pages = sysconf(_SC_PHYS_PAGES);
-	long pagesize = sysconf(_SC_PAGESIZE);
-
-	if (pages == -1 || pagesize == -1) {
-		return (0);
-	}
-
-	return ((size_t)pages * pagesize);
-#endif /* if defined(_SC_PHYS_PAGES) && defined(_SC_PAGESIZE) */
+	return ((size_t) (sysconf(_SC_PHYS_PAGES) * sysconf(_SC_PAGESIZE)));
+#endif
 	return (0);
 }
