@@ -1,13 +1,15 @@
 /*
- * Copyright (C) 2017  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-#ifndef NS_LIB_H
-#define NS_LIB_H 1
+#pragma once
 
 /*! \file include/ns/lib.h */
 
@@ -17,7 +19,6 @@
 ISC_LANG_BEGINDECLS
 
 LIBNS_EXTERNAL_DATA extern unsigned int ns_pps;
-LIBNS_EXTERNAL_DATA extern isc_msgcat_t *ns_msgcat;
 
 isc_result_t
 ns_lib_init(void);
@@ -32,5 +33,3 @@ ns_lib_shutdown(void);
  */
 
 ISC_LANG_ENDDECLS
-
-#endif /* NS_LIB_H */
